@@ -5,6 +5,7 @@ from typing import Union, List, Dict, cast, Optional
 import logging
 import pathlib
 import shutil
+import subprocess
 import platform
 import toml
 from .files.rprofile import RProfile
@@ -129,6 +130,7 @@ class Environment:
         """Initializes the environment
 
         Args:
+            r_version: the version of R to use to create the env
             r_executable_path: if specified, which R to use to create the env.
                                if not specified, one will be found.
             overwrite: If true, overwrite a pre-existing environment,
@@ -252,6 +254,20 @@ class Environment:
 
         code += textwrap.dedent(f"""
             config <- .parse_config_file()
+            current_r_version <- paste0(R.version$major, ".", R.version$minor)
+
+            if (config$r_platform != R.version$platform ||
+                config$r_version != current_r_version) {{
+                stop(
+                    paste0(
+                        "Cannot use environment '{self.name}': ",
+                        "currently running R ",
+                        current_r_version, " ", R.version$platform,
+                        ", but environment is built for R ",
+                        config$r_version, " ", config$r_platform
+                    )
+                )
+            }}
 
             message(
                 paste0(
@@ -260,24 +276,6 @@ class Environment:
                     'platform: ', config$r_platform, ')'
                 )
             )
-            if (config$r_platform != R.version$platform) {{
-                stop(
-                    paste(
-                        "Cannot use environment with current R platform",
-                        R.version$platform
-                    )
-                )
-            }}
-            current_r_version <- paste0(R.version$major, ".", R.version$minor)
-            if (config$r_version != current_r_version) {{
-                stop(
-                    paste(
-                        "Cannot use environment with current R version",
-                        current_r_version
-                    )
-                )
-            }}
-
             .libPaths(c('{self.lib_reldir.as_posix()}'))
 
             """)
@@ -422,17 +420,40 @@ def find_all_installed_r_homes() -> List[Dict]:
         except (FileNotFoundError, KeyError):
             pass
     elif plat == "Linux":
+        # First, try with the base paths
         for base_path in _BASE_LINUX_R_INSTALL_PATH_LIST:
             try:
-                version = _get_rcmd_version(base_path / "bin" / "Rcmd")
+                version = _get_r_version(base_path / "bin" / "R")
                 installed_r.append({
                     "home_path": base_path,
                     "executable_path": base_path / "bin" / "R",
                     "version": version,
                     "active": True,
                 })
-            except (FileNotFoundError, KeyError):
-                pass
+            except (FileNotFoundError,
+                    subprocess.CalledProcessError,
+                    KeyError):
+                logger.exception("Failed option")
+
+        # also try under opt, one version per subdir, which is how github
+        # seem to do it. We really need to make this whole detection
+        # thing configurable
+        try:
+            base_path = pathlib.Path("/opt/R/")
+            for entry in base_path.iterdir():
+                logger.info(f"Trying {entry.name}")
+                if re.match(r"\d+\.\d+\.\d+", str(entry.name)):
+                    version = _get_r_version(entry / "bin" / "R")
+                    installed_r.append({
+                        "home_path": entry,
+                        "executable_path": entry / "bin" / "R",
+                        "version": version,
+                        "active": True,
+                    })
+        except (FileNotFoundError,
+                subprocess.CalledProcessError,
+                KeyError):
+            logger.exception("Failed option")
 
     return installed_r
 
@@ -463,18 +484,17 @@ def _get_plist_version(path: pathlib.Path) -> str:
     raise KeyError("Invalid plist file")
 
 
-def _get_rcmd_version(path: pathlib.Path) -> str:
-    """Extract the current version from the only place it can be found
-    on linux: the Rcmd file"""
-    with open(path) as f:
-        for line in f:
-            if line.startswith("R_VERSION"):
-                m = re.match(r"R_VERSION\s*=\s*(\d\.\d\.\d)", line)
-                if m is not None:
-                    version = m.group(1)
-                    return version
+def _get_r_version(path: pathlib.Path) -> str:
+    """Extract the current version from the run of the R executable"""
 
-    raise KeyError("Invalid plist file")
+    output = subprocess.check_output([path, "--version"], encoding="utf-8")
+
+    m = re.match(r"R version\s*(\d\.\d\.\d)", output)
+    if m is None:
+        raise KeyError("Unable to find version in R output")
+
+    version = m.group(1)
+    return version
 
 
 def _find_highest_active_version() -> Optional[Dict]:
