@@ -35,11 +35,15 @@ class RemoteSource(SourceABC):
         self._packages: Dict[str, List[SourcePackage]] = {}
 
     @property
-    def archive_url(self):
+    def location(self) -> str:
+        return self.url
+
+    @property
+    def archive_url(self) -> str:
         return urljoin(self.contrib_url, "Archive/")
 
     @property
-    def contrib_url(self):
+    def contrib_url(self) -> str:
         return urljoin(self.url, "src/contrib/")
 
     def find_package(self, name: str, version: str) -> SourcePackage:
